@@ -5,12 +5,10 @@
 import networkx as nx
 import logging
 
-from fhir2dataset.timer import timing
 
 logger = logging.getLogger(__name__)
 
 
-@timing
 def join_path(graph: nx.Graph) -> list:
     """transforms the query graph into an Eulerian graph in order to be able to find an Eulerian path in it.
 
@@ -29,7 +27,6 @@ def join_path(graph: nx.Graph) -> list:
     return path
 
 
-@timing
 def clean_euler_path(eulerian_path: list) -> list:
     """Cleans a Eulerian path so that each edge (not directed) appears only once in the list. If a edge appears more than once, only the first occurrence is kept.
 
@@ -40,15 +37,7 @@ def clean_euler_path(eulerian_path: list) -> list:
         list -- cleaned Eulerian path
     """  # noqa
     path = []
-    while eulerian_path:
-        edge = eulerian_path.pop(0)
-        path.append(edge)
-        list_to_pop = []
-        for ind in range(len(eulerian_path)):
-            if edge[::-1] == eulerian_path[ind] or edge == eulerian_path[ind]:
-                list_to_pop.append(ind)
-        if list_to_pop:
-            list_to_pop.sort(reverse=True)
-            for ind in list_to_pop:
-                eulerian_path.pop(ind)
+    for edge in eulerian_path:
+        if edge not in path and edge[::-1] not in path:
+            path.append(edge)
     return path
