@@ -5,8 +5,8 @@ from pprint import pformat
 from collections import defaultdict
 
 from fhir2dataset.fhirrules_getter import FHIRRules
-from fhir2dataset.timer import timing
 from fhir2dataset.visualization_tools import custom_repr
+
 from fhir2dataset.data_class import SearchParameter, ResourceAliasInfo, Element, Elements, EdgeInfo
 
 logger = logging.getLogger(__name__)
@@ -14,17 +14,16 @@ logger = logging.getLogger(__name__)
 
 class GraphQuery:
     """Class for storing query information in the form of a graph.
-    
+
     Attributes:
         resources_alias_graph {nx.Graph} -- The nodes correspond to the aliases involved in the query (filled in the "from") and stops the reference link between 2 aliases (filled in the "join").
-        resources_alias_info {dict} -- Dictionary storing information about each alias: 
+        resources_alias_info {dict} -- Dictionary storing information about each alias:
                                         * the type of the associated resource
                                         * the elements that must be retrieved from the json of a resource
                                         * a boolean indicating whether to return the number of instances of the resource that meets all these criteria or not
         fhir_rules {Type(FHIRRules)} -- an instance of an FHIRRules object which contains information specific to the FHIR standard and the API used (for example the fhirpaths associated with the search param of a resource).
     """  # noqa
 
-    @timing
     def __init__(self, fhir_api_url: str, fhir_rules: type(FHIRRules) = None) -> None:
         """Instantiate the class and create the query object
 
@@ -35,15 +34,12 @@ class GraphQuery:
             fhir_rules {type(FHIRRules)} -- an instance of a FHIRRules-type object. If the instance is not filled a default version will be used. (default: {None})
         """  # noqa
         self.fhir_api_url = fhir_api_url
-        if not fhir_rules:
-            fhir_rules = FHIRRules(fhir_api_url=self.fhir_api_url)
-        self.fhir_rules = fhir_rules
+        self.fhir_rules = fhir_rules or FHIRRules(fhir_api_url=self.fhir_api_url)
 
         # to represent the relationships (references) between resources
         self.resources_alias_graph = nx.Graph()
         self.resources_alias_info = defaultdict(Type[ResourceAliasInfo])
 
-    @timing
     def execute(
         self,
         select_dict: dict,
@@ -52,7 +48,7 @@ class GraphQuery:
         where_dict: dict = None,
         default_element_concat_type: str = "cell",
     ):
-        """Populates the attributes resources_alias_graph and resources_alias_info according to the information filled in 
+        """Populates the attributes resources_alias_graph and resources_alias_info according to the information filled in
 
         Arguments:
             select_dict {dict} -- dictionary containing the elements to be selected from the different resources
@@ -69,13 +65,16 @@ class GraphQuery:
         if where_dict:
             self._where(**where_dict)
         self._select(**select_dict)
+
+        for resource_alias in self.resources_alias_info.keys():
+            self.resources_alias_info[resource_alias].elements.compute_forest_fhirpaths()
+
         logger.info(f"The nodes are:{self.resources_alias_graph.nodes()}")
         logger.info("The edges are:")
         logger.info(pformat(list(self.resources_alias_graph.edges(data=True))))
         logger.info("The information gathered for each node is:")
         logger.info(pformat(self.resources_alias_info))
 
-    @timing
     def from_config(self, config: dict):
         """Populates the attributes resources_alias_graph and resources_alias_info according to the information given in the configuration file
 
@@ -89,14 +88,13 @@ class GraphQuery:
             join_dict=config.get("join"),
         )
 
-    @timing
     def _from(self, **resource_type_alias):
         """Initializes the graph nodes contained in resources_alias_graph and the dictionary of resources_alias_info information of the aliases listed in resource_type_alias
 
         Keyword Arguments:
             **resource_type_alias: the key corresponds to the alias and the value to the type of the resource.
         """  # noqa
-        for (resource_alias, resource_type,) in resource_type_alias.items():
+        for (resource_alias, resource_type) in resource_type_alias.items():
             elements = Elements(
                 [
                     Element(
@@ -114,7 +112,6 @@ class GraphQuery:
                 alias=resource_alias, resource_type=resource_type, elements=elements
             )
 
-    @timing
     def _join(self, **join_as):
         """Builds the reference links between the aliases involved in the query
         1. fills in the elements in attribute resources_alias_info to be retrieved from the json resource file to be able to make the joins
@@ -129,16 +126,16 @@ class GraphQuery:
             assert join_how in ["inner", "child", "parent", "one"], "Precise how to join"
             for (alias_parent, searchparam_dict) in relationships_dict.items():
                 type_parent = self.resources_alias_info[alias_parent].resource_type
-                for (searchparam_parent, alias_child,) in searchparam_dict.items():
+                for (searchparam_parent, alias_child) in searchparam_dict.items():
 
                     # Update element to have in table
                     fhirpath_searchparam = self.fhir_rules.searchparam_to_fhirpath(
-                        resource_type=type_parent, search_param=searchparam_parent,
+                        resource_type=type_parent, search_param=searchparam_parent
                     )
                     if " | " in fhirpath_searchparam:
-                        fhirpath_ref = f"({fhirpath_searchparam}).reference"
+                        fhirpath_ref = f"(({fhirpath_searchparam}).reference)"
                     else:
-                        fhirpath_ref = f"{fhirpath_searchparam}.reference"
+                        fhirpath_ref = f"({fhirpath_searchparam}.reference)"
 
                     self.resources_alias_info[alias_parent].elements.append(
                         Element(
@@ -173,7 +170,6 @@ class GraphQuery:
 
                     self.resources_alias_graph.add_edge(alias_parent, alias_child, info=edge_info)
 
-    @timing
     def _where(self, **wheres):
         """updates the resources_alias_info attribute with the conditions that each alias must meet
 
@@ -205,7 +201,6 @@ class GraphQuery:
                     )
                 )
 
-    @timing
     def _select(self, **selects):
         """updates the resources_alias_info attribute with the elements that must be retrieved for each alias
 
@@ -216,10 +211,9 @@ class GraphQuery:
             for col_name in col_names:
                 fhirpath = self._check_searchparam_or_fhirpath(resource_alias, col_name)
                 self.resources_alias_info[resource_alias].elements.append(
-                    Element(goal="select", col_name=col_name, fhirpath=fhirpath,)
+                    Element(goal="select", col_name=col_name, fhirpath=fhirpath)
                 )
 
-    @timing
     def _check_searchparam_or_fhirpath(self, resource_alias: str, searchparam_or_fhirpath: str):
         """transforms searchparam_or_fhirpath into its fhirpath if it's a searchparam, otherwise it returns the argument as it was entered.
 
@@ -232,7 +226,8 @@ class GraphQuery:
         """  # noqa
         resource_type = self.resources_alias_info[resource_alias].resource_type
         searchparam_to_element = self.fhir_rules.searchparam_to_fhirpath(
-            resource_type=resource_type, search_param=searchparam_or_fhirpath,
+            resource_type=resource_type,
+            search_param=searchparam_or_fhirpath,
         )
         if searchparam_to_element:
             element = searchparam_to_element
@@ -240,13 +235,11 @@ class GraphQuery:
             element = searchparam_or_fhirpath
         return element
 
-    @timing
     def draw_relations(self):
-        """draws the resources_alias_graph attribute
-        """
+        """draws the resources_alias_graph attribute"""
         import matplotlib.pyplot as plt
 
-        edge_labels = dict()
+        edge_labels = {}
         for i in self.resources_alias_graph.edges(data=True):
             edge_infos = custom_repr(i[2]["info"].__repr__())
             edge_labels[i[0:2]] = edge_infos
